@@ -2,8 +2,8 @@
 #
 # ==========================================================================
 #
-# ZoneMinder Daemon Control Script, $Date: 2006-10-24 11:58:00 +0100 (Tue, 24 Oct 2006) $, $Revision: 2029 $
-# Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+# ZoneMinder Daemon Control Script, $Date: 2008-12-05 21:13:19 +0000 (Fri, 05 Dec 2008) $, $Revision: 2701 $
+# Copyright (C) 2001-2008 Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -543,9 +543,30 @@ if ( !$server_up )
 				my $core_dumped = $status&0x01;
 
 				my $out_str = "'$process->{daemon} ".join( ' ', @{$process->{args}} )."' ";
-				$out_str .= $exit_signal?"crashed":("exited ".(($exit_status==0)?"normally":"abnormally"));
-				$out_str .= ", exit status $exit_status" if ( $exit_status );
-				$out_str .= ", signal $exit_signal" if ( $exit_signal );
+                if ( $exit_signal )
+                {
+                    if ( $exit_signal == 15 || $exit_signal == 14 ) # TERM or ALRM
+                    {
+				        $out_str .= "exited";
+                    }
+                    else
+                    {
+				        $out_str .= "crashed";
+                    }
+				    $out_str .= ", signal $exit_signal";
+                }
+                else
+                {
+				    $out_str .= "exited ";
+                    if ( $exit_status )
+                    {
+				        $out_str .= "abnormally, exit status $exit_status";
+                    }
+                    else
+                    {
+                        $out_str .= "normally";
+                    }
+                }
 				#print( ", core dumped" ) if ( $core_dumped );
 				$out_str .= "\n";
 
@@ -560,7 +581,7 @@ if ( !$server_up )
 
 				if ( $process->{keepalive} )
 				{
-					if ( !$process->{delay} || ($process->{runtime} > (10*$process->{delay})) )
+					if ( !$process->{delay} || ($process->{runtime} > ZM_MAX_RESTART_DELAY) )
 					{
 						#start( $process->{daemon}, @{$process->{args}} );
 						# Schedule for immediate restart
