@@ -2,8 +2,8 @@
 #
 # ==========================================================================
 #
-# ZoneMinder Package Control Script, $Date: 2007-11-04 17:30:29 +0000 (Sun, 04 Nov 2007) $, $Revision: 2229 $
-# Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+# ZoneMinder Package Control Script, $Date: 2008-07-25 10:48:16 +0100 (Fri, 25 Jul 2008) $, $Revision: 2612 $
+# Copyright (C) 2001-2008 Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -142,7 +142,7 @@ if ( $command =~ /^(?:stop|restart)$/ )
 	if ( $status eq "running" )
 	{
 		runCommand( "zmdc.pl shutdown" );
-		removeShm();
+		zmMemTidy();
 	}
 	else
 	{
@@ -156,7 +156,7 @@ if ( $command =~ /^(?:start|restart)$/ )
 
 	if ( $status eq "stopped" )
 	{
-		removeShm();
+		zmMemTidy();
 		runCommand( "zmfix" );
 		runCommand( "zmdc.pl startup" );
 
@@ -305,28 +305,6 @@ sub getCmdFormat
 	exit( -1 );
 }
 
-sub removeShm
-{
-	Debug( "Removing shared memory\n" );
-	# Find ZoneMinder shared memory
-	my $command = "ipcs -m | grep '^".substr( sprintf( "0x%x", hex(ZM_SHM_KEY) ), 0, -2 )."'";
-	Debug( "Checking for shared memory with '$command'\n" );
-	open( CMD, "$command |" ) or Fatal( "Can't execute '$command': $!" );
-	while( <CMD> )
-	{
-		chomp;
-		my ( $key, $id ) = split( /\s+/ );
-		if ( $id =~ /^(\d+)/ )
-		{
-			$id = $1;
-			$command = "ipcrm shm $id";
-			Debug( "Removing shared memory with '$command'\n" );
-			qx( $command );
-		}
-	}
-	close( CMD );
-}
-
 sub runCommand
 {
 	my $command = shift;
