@@ -2,8 +2,8 @@
 #
 # ==========================================================================
 #
-# ZoneMinder Experimental PTZ Tracking Script, $Date: 2008-03-10 09:43:48 +0000 (Mon, 10 Mar 2008) $, $Revision: 2344 $
-# Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+# ZoneMinder Experimental PTZ Tracking Script, $Date: 2008-07-25 10:48:16 +0100 (Fri, 25 Jul 2008) $, $Revision: 2612 $
+# Copyright (C) 2001-2008 Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -121,7 +121,7 @@ if ( !$monitor->{CanMoveMap} )
 }
 
 Debug( "Found monitor for id '$monitor'\n" );
-exit( -1 ) if ( !zmShmVerify( $monitor ) );
+exit( -1 ) if ( !zmMemVerify( $monitor ) );
 
 sub Suspend
 {
