@@ -2,8 +2,8 @@
 #
 # ==========================================================================
 #
-# ZoneMinder WatchDog Script, $Date: 2007-09-07 16:39:44 +0100 (Fri, 07 Sep 2007) $, $Revision: 2198 $
-# Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+# ZoneMinder WatchDog Script, $Date: 2008-10-28 12:52:39 +0000 (Tue, 28 Oct 2008) $, $Revision: 2675 $
+# Copyright (C) 2001-2008 Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -84,40 +84,63 @@ while( 1 )
 	{
 		if ( $monitor->{Function} ne 'None' )
 		{
-			if ( zmShmVerify( $monitor ) && zmShmRead( $monitor, "shared_data:valid" ) )
+            my $restart = 0;
+			if ( zmMemVerify( $monitor ) && zmMemRead( $monitor, "shared_data:valid" ) )
 			{
 				# Check we have got an image recently
-				my $image_time = zmGetLastImageTime( $monitor );
-				next if ( !defined($image_time) ); # Can't read from shared memory
+				my $image_time = zmGetLastWriteTime( $monitor );
+				next if ( !defined($image_time) ); # Can't read from shared data
 				next if ( !$image_time ); # We can't get the last capture time so can't be sure it's died.
 
 				my $max_image_delay = ($monitor->{MaxFPS}&&($monitor->{MaxFPS}>0)&&($monitor->{MaxFPS}<1))?(3/$monitor->{MaxFPS}):ZM_WATCH_MAX_DELAY;
 				my $image_delay = $now-$image_time;
 				Debug( "Monitor $monitor->{Id} last captured $image_delay seconds ago, max is $max_image_delay\n" );
-				if ( $image_delay <= $max_image_delay )
+				if ( $image_delay > $max_image_delay )
 				{
-					# Yes, so continue
-					next;
-				}
-				Info( "Restarting capture daemon for ".$monitor->{Name}.", time since last capture $image_delay seconds ($now-$image_time)\n" );
+				    Info( "Restarting capture daemon for ".$monitor->{Name}.", time since last capture $image_delay seconds ($now-$image_time)\n" );
+                    $restart = 1;
+                }
 			}
 			else
 			{
-				Info( "Restarting capture daemon for ".$monitor->{Name}.", shared memory not valid\n" );
+				#Info( "Restarting capture daemon for ".$monitor->{Name}.", shared data not valid\n" );
+                #$restart = 1;
 			}
 
-			my $command;
-			# If we are here then something bad has happened
-			if ( $monitor->{Type} eq 'Local' )
-			{
-				$command = ZM_PATH_BIN."/zmdc.pl restart zmc -d $monitor->{Device}";
-			}
-			else
-			{
-				$command = ZM_PATH_BIN."/zmdc.pl restart zmc -m $monitor->{Id}";
-			}
-			Info( qx( $command ) );
-		}
+            if ( $restart )
+            {
+                my $command;
+                if ( $monitor->{Type} eq 'Local' )
+                {
+                    $command = ZM_PATH_BIN."/zmdc.pl restart zmc -d $monitor->{Device}";
+                }
+                else
+                {
+                    $command = ZM_PATH_BIN."/zmdc.pl restart zmc -m $monitor->{Id}";
+                }
+                Info( qx( $command ) );
+            }
+            elsif ( $monitor->{Function} ne 'Monitor' )
+            {
+                if ( zmMemVerify( $monitor ) && zmMemRead( $monitor, "shared_data:valid" ) )
+                {
+                    # Check we have got an image recently
+                    my $image_time = zmGetLastReadTime( $monitor );
+                    next if ( !defined($image_time) ); # Can't read from shared data
+                    next if ( !$image_time ); # We can't get the last capture time so can't be sure it's died.
+
+                    my $max_image_delay = ($monitor->{MaxFPS}&&($monitor->{MaxFPS}>0)&&($monitor->{MaxFPS}<1))?(3/$monitor->{MaxFPS}):ZM_WATCH_MAX_DELAY;
+                    my $image_delay = $now-$image_time;
+                    Debug( "Monitor $monitor->{Id} last analysed $image_delay seconds ago, max is $max_image_delay\n" );
+                    if ( $image_delay > $max_image_delay )
+                    {
+                        Info( "Restarting analysis daemon for ".$monitor->{Name}.", time since last analysis $image_delay seconds ($now-$image_time)\n" );
+                        my $command = ZM_PATH_BIN."/zmdc.pl restart zma -m ".$monitor->{Id};
+                        Info( qx( $command ) );
+                    }
+                }
+            }
+        }
 	}
 	sleep( ZM_WATCH_CHECK_INTERVAL );
 }
