@@ -2,8 +2,8 @@
 #
 # ==========================================================================
 #
-# ZoneMinder X10 Control Script, $Date: 2008-04-21 15:02:43 +0100 (Mon, 21 Apr 2008) $, $Revision: 2392 $
-# Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+# ZoneMinder X10 Control Script, $Date: 2008-07-25 10:48:16 +0100 (Fri, 25 Jul 2008) $, $Revision: 2612 $
+# Copyright (C) 2001-2008 Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -425,7 +425,7 @@ sub loadTasks
 	my $res = $sth->execute() or Fatal( "Can't execute: ".$sth->errstr() );
 	while( my $monitor = $sth->fetchrow_hashref() )
 	{
-		next if ( !zmShmVerify( $monitor ) ); # Check shared memory ok
+		next if ( !zmMemVerify( $monitor ) ); # Check shared memory ok
 
 		$monitor_hash{$monitor->{Id}} = $monitor;
 
