@@ -1,6 +1,6 @@
 //
-// ZoneMinder Image Class Interface, $Date: 2008-02-13 22:44:19 +0000 (Wed, 13 Feb 2008) $, $Revision: 2305 $
-// Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+// ZoneMinder Image Class Interface, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+// Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -28,11 +28,11 @@
 #include <math.h>
 #include <zlib.h>
 
+#include "zm.h"
 extern "C"
 {
 #include "zm_jpeg.h"
 }
-
 #include "zm_rgb.h"
 #include "zm_coord.h"
 #include "zm_box.h"
@@ -124,7 +124,7 @@ public:
 	{
 		if ( image.size != size )
         {
-            Fatal(( "Attempt to copy different size image buffers, expected %d, got %d", size, image.size ));
+            Fatal( "Attempt to copy different size image buffers, expected %d, got %d", size, image.size );
         }
 		memcpy( buffer, image.buffer, size );
 	}
