@@ -1,6 +1,6 @@
 //
-// ZoneMinder Monitor Class Interfaces, $Date: 2008-03-13 13:36:12 +0000 (Thu, 13 Mar 2008) $, $Revision: 2357 $
-// Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+// ZoneMinder Monitor Class Interfaces, $Date: 2009-02-12 21:32:00 +0000 (Thu, 12 Feb 2009) $, $Revision: 2755 $
+// Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -22,14 +22,20 @@
 
 #include <sys/time.h>
 
+#include "zm.h"
 #include "zm_coord.h"
 #include "zm_image.h"
 #include "zm_zone.h"
+#include "zm_event.h"
 #include "zm_camera.h"
 
+#define SIGNAL_CAUSE "Signal"
+#define MOTION_CAUSE "Motion"
+#define LINKED_CAUSE "Linked"
+
 //
 // This is the main class for monitors. Each monitor is associated
-// with a camera and is effectivaly a collector for events.
+// with a camera and is effectively a collector for events.
 //
 class Monitor
 {
@@ -73,8 +79,12 @@ public:
 	} State;
 
 protected:
+    typedef std::set<Zone *> ZoneSet;
+
 	typedef enum { GET_SETTINGS=0x1, SET_SETTINGS=0x2, RELOAD=0x4, SUSPEND=0x10, RESUME=0x20 } Action;
 
+	typedef enum { CLOSE_TIME, CLOSE_IDLE, CLOSE_ALARM } EventCloseMode;
+
 	typedef struct
 	{
 		int size;
@@ -84,7 +94,8 @@ protected:
 		State state;
 		int last_write_index;
 		int last_read_index;
-		time_t last_image_time;
+		time_t last_write_time;
+		time_t last_read_time;
 		int last_event;
 		int action;
 		int brightness;
@@ -107,7 +118,7 @@ protected:
 		char trigger_showtext[256];
 	} TriggerData;
 
-	typedef struct Snapshot
+	struct Snapshot
 	{
 		struct timeval	*timestamp;
 		Image	*image;
@@ -122,9 +133,14 @@ protected:
 		bool			connected;
 		time_t			last_connect_time;
 
-		int				shm_id;
-		int				shm_size;
-		unsigned char	*shm_ptr;
+#if ZM_MEM_MAPPED
+		int				map_fd;
+        char            mem_file[PATH_MAX];
+#else // ZM_MEM_MAPPED
+        int             shm_id;
+#endif // ZM_MEM_MAPPED
+		int				mem_size;
+		unsigned char	*mem_ptr;
 
 		SharedData		*shared_data;
 		TriggerData		*trigger_data;
@@ -182,7 +198,7 @@ protected:
 	int				warmup_count;		    // How many images to process before looking for events
 	int				pre_event_count;	    // How many images to hold and prepend to an alarm event
 	int				post_event_count;	    // How many unalarmed images must occur before the alarm state is reset
-	int				stream_replay_buffer;   // How many frames to store to support DVR functions
+	int				stream_replay_buffer;   // How many frames to store to support DVR functions, IGNORED from this object, passed directly into zms now
 	int				section_length;		    // How long events should last in continuous modes
 	int				frame_skip;			    // How many frames to skip in continuous modes
 	int				capture_delay;		    // How long we wait between capture frames
@@ -210,9 +226,16 @@ protected:
 	time_t			last_fps_time;
 	time_t			auto_resume_time;
 
-	int				shm_id;
-	int				shm_size;
-	unsigned char	*shm_ptr;
+    EventCloseMode  event_close_mode;
+
+#if ZM_MEM_MAPPED
+	int				map_fd;
+    char            mem_file[PATH_MAX];
+#else // ZM_MEM_MAPPED
+    int             shm_id;
+#endif // ZM_MEM_MAPPED
+	int				mem_size;
+	unsigned char	*mem_ptr;
 
 	SharedData		*shared_data;
 	TriggerData		*trigger_data;
@@ -312,9 +335,13 @@ public:
 	{
 		return( camera->PreCapture() );
 	}
-	int PostCapture();
+	int Capture();
+	int PostCapture()
+	{
+		return( camera->PostCapture() );
+	}
 
-	unsigned int DetectMotion( const Image &comp_image, char *text_ptr=0, size_t text_size=0 );
+	unsigned int DetectMotion( const Image &comp_image, Event::StringSet &zoneSet );
 	bool CheckSignal( const Image *image );
 	bool Analyse();
 	void DumpImage( Image *dump_image ) const;
@@ -329,8 +356,11 @@ public:
 	void DumpZoneImage( const char *zone_string=0 );
 
 	static int LoadLocalMonitors( const char *device, Monitor **&monitors, Purpose purpose );
-	static int LoadRemoteMonitors( const char *host, const char*port, const char*path, Monitor **&monitors, Purpose purpose );
+	static int LoadRemoteMonitors( const char *protocol, const char *host, const char*port, const char*path, Monitor **&monitors, Purpose purpose );
 	static int LoadFileMonitors( const char *file, Monitor **&monitors, Purpose purpose );
+#if HAVE_LIBAVFORMAT
+	static int LoadFfmpegMonitors( const char *file, Monitor **&monitors, Purpose purpose );
+#endif // HAVE_LIBAVFORMAT
 	static Monitor *Load( int id, bool load_zones, Purpose purpose );
     //void writeStreamImage( Image *image, struct timeval *timestamp, int scale, int mag, int x, int y );
 	//void StreamImages( int scale=100, int maxfps=10, time_t ttl=0, int msq_id=0 );
@@ -365,7 +395,7 @@ protected:
     time_t ttl;
 
 protected:
-    bool buffer_playback;
+    int playback_buffer;
     bool delayed;
 
     int frame_count;
@@ -373,16 +403,17 @@ protected:
 protected:
     bool checkSwapPath( const char *path, bool create_path );
 
-    void sendFrame( const char *filepath, struct timeval *timestamp );
-    void sendFrame( Image *image, struct timeval *timestamp );
+    bool sendFrame( const char *filepath, struct timeval *timestamp );
+    bool sendFrame( Image *image, struct timeval *timestamp );
     void processCommand( const CmdMsg *msg );
 
 public:
-    MonitorStream()
+    MonitorStream() : playback_buffer( 0 ), delayed( false ), frame_count( 0 )
     {
-        buffer_playback = false;
-        delayed = false;
-        frame_count = 0;
+    }
+    void setStreamBuffer( int p_playback_buffer )
+    {
+        playback_buffer = p_playback_buffer;
     }
     void setStreamTTL( time_t p_ttl )
     {
