@@ -1,6 +1,6 @@
 /*
- * ZoneMinder MPEG Interface, $Date: 2007-12-17 13:17:09 +0000 (Mon, 17 Dec 2007) $, $Revision: 2256 $
- * Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+ * ZoneMinder MPEG Interface, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+ * Copyright (C) 2001-2008 Philip Coombes
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,32 +17,12 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */  
 
-#include "zm.h"
-
-#if HAVE_LIBAVCODEC
-
 #ifndef ZM_MPEG_H
 #define ZM_MPEG_H
 
-extern "C" {
-#define __STDC_CONSTANT_MACROS
-#include <ffmpeg/avformat.h>
-#if HAVE_LIBSWSCALE
-#include <ffmpeg/swscale.h>
-#endif // HAVE_LIBSWSCALE
-}
+#include "zm_ffmpeg.h"
 
-#if FFMPEG_VERSION_INT == 0x000408
-#define ZM_FFMPEG_048	1
-#elif FFMPEG_VERSION_INT == 0x000409
-#if LIBAVCODEC_VERSION_INT < ((50<<16)+(0<<8)+0)
-#define ZM_FFMPEG_049	1
-#else // LIBAVCODEC_VERSION_INT
-#define ZM_FFMPEG_SVN	1
-#endif // LIBAVCODEC_VERSION_INT
-#else // FFMPEG_VERSION_INT
-#define ZM_FFMPEG_SVN	1
-#endif // FFMPEG_VERSION_INT
+#if HAVE_LIBAVCODEC
 
 class VideoStream
 {
@@ -85,6 +65,6 @@ public:
 	double EncodeFrame( uint8_t *buffer, int buffer_size, bool add_timestamp=false, unsigned int timestamp=0 );
 };
 
-#endif // ZM_MPEG_H
-                               
 #endif // HAVE_LIBAVCODEC
+
+#endif // ZM_MPEG_H
