@@ -1,6 +1,6 @@
 //
-// ZoneMinder Analysis Daemon, $Date: 2008-03-13 13:36:12 +0000 (Thu, 13 Mar 2008) $, $Revision: 2357 $
-// Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+// ZoneMinder Analysis Daemon, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+// Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -96,7 +96,7 @@ int main( int argc, char *argv[] )
 
 	if ( monitor )
 	{
-		Info(( "In mode %d/%d, warming up", monitor->GetFunction(), monitor->Enabled() ));
+		Info( "In mode %d/%d, warming up", monitor->GetFunction(), monitor->Enabled() );
 
 		if ( config.opt_frame_server )
 		{
