@@ -1,6 +1,6 @@
 //
-// ZoneMinder Capture Daemon, $Date: 2008-03-13 13:36:12 +0000 (Thu, 13 Mar 2008) $, $Revision: 2357 $
-// Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+// ZoneMinder Capture Daemon, $Date: 2009-02-18 12:30:17 +0000 (Wed, 18 Feb 2009) $, $Revision: 2776 $
+// Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -23,25 +23,27 @@
 
 #include "zm.h"
 #include "zm_db.h"
+#include "zm_time.h"
 #include "zm_signal.h"
 #include "zm_monitor.h"
 
 void Usage()
 {
-	fprintf( stderr, "zmc -d <device_path> or -H <host> -P <port> -p <path> or -f <file_path> or -m <monitor_id>\n" );
+	fprintf( stderr, "zmc -d <device_path> or -r <proto> -H <host> -P <port> -p <path> or -f <file_path> or -m <monitor_id>\n" );
 
 	fprintf( stderr, "Options:\n" );
-	fprintf( stderr, "  -d, --device <device_path>    : For local cameras, device to access. E.g /dev/video0 etc\n" );
-	fprintf( stderr, "  -H <host> -P <port> -p <path> : For remote cameras\n" );
-	fprintf( stderr, "  -f, --file <file_path>        : For local images, jpg file to access.\n" );
-	fprintf( stderr, "  -m, --monitor <monitor_id>    : For sources associated with a single monitor\n" );
-	fprintf( stderr, "  -h, --help                    : This screen\n" );
+	fprintf( stderr, "  -d, --device <device_path>               : For local cameras, device to access. E.g /dev/video0 etc\n" );
+	fprintf( stderr, "  -r <proto> -H <host> -P <port> -p <path> : For remote cameras\n" );
+	fprintf( stderr, "  -f, --file <file_path>                   : For local images, jpg file to access.\n" );
+	fprintf( stderr, "  -m, --monitor <monitor_id>               : For sources associated with a single monitor\n" );
+	fprintf( stderr, "  -h, --help                               : This screen\n" );
 	exit( 0 );
 }
 
 int main( int argc, char *argv[] )
 {
 	const char *device = "";
+	const char *protocol = "";
 	const char *host = "";
 	const char *port = "";
 	const char *path = "";
@@ -50,6 +52,7 @@ int main( int argc, char *argv[] )
 
 	static struct option long_options[] = {
 		{"device", 1, 0, 'd'},
+		{"protocol", 1, 0, 'r'},
 		{"host", 1, 0, 'H'},
 		{"port", 1, 0, 'P'},
 	 	{"path", 1, 0, 'p'},
@@ -157,7 +160,7 @@ int main( int argc, char *argv[] )
 	{
 		if ( !port )
 			port = "80";
-		n_monitors = Monitor::LoadRemoteMonitors( host, port, path, monitors, Monitor::CAPTURE );
+		n_monitors = Monitor::LoadRemoteMonitors( protocol, host, port, path, monitors, Monitor::CAPTURE );
 	}
 	else if ( file[0] )
 	{
@@ -176,11 +179,11 @@ int main( int argc, char *argv[] )
 
 	if ( !n_monitors )
 	{
-		Error(( "No monitors found" ));
+		Error( "No monitors found" );
 		exit ( -1 );
 	}
 
-	Info(( "Starting Capture" ));
+	Info( "Starting Capture" );
 
 	zmSetDefaultTermHandler();
 	zmSetDefaultDieHandler();
@@ -193,7 +196,7 @@ int main( int argc, char *argv[] )
 
 	if ( monitors[0]->PrimeCapture() < 0 )
 	{
-        Error(( "Failed to prime capture of initial monitor" ));
+        Error( "Failed to prime capture of initial monitor" );
 		exit( -1 );
 	}
 
@@ -208,6 +211,7 @@ int main( int argc, char *argv[] )
 		alarm_capture_delays[i] = monitors[i]->GetAlarmCaptureDelay();
 	}
 
+    int result = 0;
 	struct timeval now;
 	struct DeltaTimeval delta_time;
 	while( !zm_terminate )
@@ -244,13 +248,24 @@ int main( int argc, char *argv[] )
 			{
 				if ( monitors[i]->PreCapture() < 0 )
 				{
-                    Error(( "Failed to pre-capture monitor %d", i ));
-					exit( -1 );
+                    Error( "Failed to pre-capture monitor %d (%d/%d)", monitors[i]->Id(), i, n_monitors );
+                    zm_terminate = true;
+                    result = -1;
+                    break;
+				}
+				if ( monitors[i]->Capture() < 0 )
+				{
+                    Error( "Failed to capture image from monitor %d (%d/%d)", monitors[i]->Id(), i, n_monitors );
+                    zm_terminate = true;
+                    result = -1;
+                    break;
 				}
 				if ( monitors[i]->PostCapture() < 0 )
 				{
-                    Error(( "Failed to post-capture monitor %d", i ));
-					exit( -1 );
+                    Error( "Failed to post-capture monitor %d (%d/%d)", monitors[i]->Id(), i, n_monitors );
+                    zm_terminate = true;
+                    result = -1;
+                    break;
 				}
 
 				if ( next_delays[i] > 0 )
@@ -276,5 +291,5 @@ int main( int argc, char *argv[] )
 	delete [] next_delays;
 	delete [] last_capture_times;
 
-	return( 0 );
+	return( result );
 }
