@@ -1,6 +1,6 @@
 //
-// ZoneMinder Streaming Server, $Date: 2007-11-20 17:06:45 +0000 (Tue, 20 Nov 2007) $, $Revision: 2245 $
-// Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+// ZoneMinder Streaming Server, $Date: 2008-10-29 23:08:21 +0000 (Wed, 29 Oct 2008) $, $Revision: 2679 $
+// Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -44,7 +44,7 @@ bool ValidateAccess( User *user, int mon_id )
 	}
 	if ( !allowed )
 	{
-		Error(( "Error, insufficient privileges for requested action" ));
+		Error( "Error, insufficient privileges for requested action" );
 		exit( -1 );
 	}
 	return( allowed );
@@ -69,6 +69,7 @@ int main( int argc, const char *argv[] )
 	char password[64] = "";
 	char auth[64] = "";
     unsigned int connkey = 0;
+    unsigned int playback_buffer = 0;
 
 	bool nph = false;
 	const char *basename = strrchr( argv[0], '/' );
@@ -88,7 +89,7 @@ int main( int argc, const char *argv[] )
 	const char *query = getenv( "QUERY_STRING" );
 	if ( query )
 	{
-		Debug( 1, ( "Query: %s", query ));
+		Debug( 1, "Query: %s", query );
 	
 		char temp_query[1024];
 		strncpy( temp_query, query, sizeof(temp_query) );
@@ -106,7 +107,7 @@ int main( int argc, const char *argv[] )
 			char *name = strtok( parms[p], "=" );
 			char *value = strtok( NULL, "=" );
             if ( !value )
-                value = "";
+                value = (char *)"";
 			if ( !strcmp( name, "source" ) )
 			{
 				source = !strcmp( value, "event" )?ZMS_EVENT:ZMS_MONITOR;
@@ -145,6 +146,8 @@ int main( int argc, const char *argv[] )
 			}
 			else if ( !strcmp( name, "connkey" ) )
 				connkey = atoi(value);
+			else if ( !strcmp( name, "buffer" ) )
+				playback_buffer = atoi(value);
 			else if ( config.opt_use_auth )
 			{
 				if ( strcmp( config.auth_relay, "none" ) == 0 )
@@ -209,7 +212,7 @@ int main( int argc, const char *argv[] )
 		}
 		if ( !user )
 		{
-			Error(( "Unable to authenticate user" ));
+			Error( "Unable to authenticate user" );
 			return( -1 );
 		}
 		ValidateAccess( user, monitor_id );
@@ -245,6 +248,7 @@ int main( int argc, const char *argv[] )
         stream.setStreamMaxFPS( maxfps );
         stream.setStreamTTL( ttl );
         stream.setStreamQueue( connkey );
+        stream.setStreamBuffer( playback_buffer );
         stream.setStreamStart( monitor_id );
 
         if ( mode == ZMS_JPEG )
@@ -270,7 +274,7 @@ int main( int argc, const char *argv[] )
             stream.setStreamBitrate( bitrate );
             stream.setStreamType( MonitorStream::STREAM_MPEG );
 #else // HAVE_LIBAVCODEC
-            Error(( "MPEG streaming of '%s' attempted while disabled", query ));
+            Error( "MPEG streaming of '%s' attempted while disabled", query );
             fprintf( stderr, "MPEG streaming is disabled.\nYou should configure with the --with-ffmpeg option and rebuild to use this functionality.\n" );
             return( -1 );
 #endif // HAVE_LIBAVCODEC
@@ -304,8 +308,8 @@ int main( int argc, const char *argv[] )
             stream.setStreamBitrate( bitrate );
             stream.setStreamType( EventStream::STREAM_MPEG );
 #else // HAVE_LIBAVCODEC
-            Error(( "MPEG streaming of '%s' attempted while disabled", query ));
-            fprintf( stderr, "MPEG streaming is disabled.\nYou should configure with the --with-ffmpeg option and rebuild to use this functionality.\n" );
+            Error( "MPEG streaming of '%s' attempted while disabled", query );
+            fprintf( stderr, "MPEG streaming is disabled.\nYou should ensure the ffmpeg libraries are installed and detected and rebuild to use this functionality.\n" );
             return( -1 );
 #endif // HAVE_LIBAVCODEC
         }
