@@ -1,6 +1,6 @@
 //
-// ZoneMinder Control Utility, $Date: 2008-02-13 22:44:37 +0000 (Wed, 13 Feb 2008) $, $Revision: 2306 $
-// Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
+// ZoneMinder Control Utility, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+// Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -678,18 +678,18 @@ int main( int argc, char *argv[] )
 
 			if ( mysql_query( &dbconn, sql ) )
 			{
-				Error(( "Can't run query: %s", mysql_error( &dbconn ) ));
+				Error( "Can't run query: %s", mysql_error( &dbconn ) );
 				exit( mysql_errno( &dbconn ) );
 			}
 
 			MYSQL_RES *result = mysql_store_result( &dbconn );
 			if ( !result )
 			{
-				Error(( "Can't use query result: %s", mysql_error( &dbconn ) ));
+				Error( "Can't use query result: %s", mysql_error( &dbconn ) );
 				exit( mysql_errno( &dbconn ) );
 			}
 			int n_monitors = mysql_num_rows( result );
-			Debug( 1, ( "Got %d monitors", n_monitors ));
+			Debug( 1, "Got %d monitors", n_monitors );
 
 			printf( "%4s%5s%6s%9s%14s%6s%6s%8s%8s\n", "Id", "Func", "State", "TrgState", "LastImgTim", "RdIdx", "WrIdx", "LastEvt", "FrmRate" );
 			for( int i = 0; MYSQL_ROW dbrow = mysql_fetch_row( result ); i++ )
